bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGamma.plates_multiplier
==========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. autoattribute:: WrapToGaussianGamma.plates_multiplier